#[repr(u8)]pub enum HashTableError {
AllocationError = 0,
LengthLimitExceeded = 1,
AllocatorCloningError = 2,
}Expand description
Represents a general issue that can occure when dealing with hash tables.
Variants
AllocationError = 0
The underlying allocator returned an error, likely due to out of memory.
LengthLimitExceeded = 1
Tried to initialize a hash table or push to it beyond its internal limit.
AllocatorCloningError = 2
The underlying allocator cloning failed.